@@ -26,10 +26,6 @@ class QalxItem(QalxValidateBlueprintAdapter, QalxFileAdapter):
         blueprint_name=None,
         **kwargs,
     ):
-        if not any([data, input_file]):
-            raise QalxError(
-                "At least one of `data` or `input_file` is required"
-            )
         if data is None:
             data = {}
         return super(QalxItem, self)._validate(
